Internal API of Output
======================

.. seealso::

   Documentation on  :class:`fluidsim:fluidsim_core.output.OutputCore` which is the base class for :class:`snek5000.output.base.Output`.

.. automethod:: snek5000.output.base.Output._complete_info_solver
.. automethod:: snek5000.output.base.Output._set_info_solver_classes
.. automethod:: snek5000.output.base.Output._complete_params_with_default
.. automethod:: snek5000.output.base.Output._init_sim_repr_maker
.. automethod:: snek5000.output.base.Output._get_resources
.. automethod:: snek5000.output.base.Output._get_subpackages
.. automethod:: snek5000.output.base.Output._save_info_solver_params_xml


.. _nek5000make:

Class _Nek5000Make
------------------

:meth:`snek5000.output.base.Output.build_nek5000` relies on:

.. autoclass:: snek5000.make._Nek5000Make
